pub struct BufReader<S: AsRef<[u8]>> { /* private fields */ }Expand description
A buffered reader for byte slices that tracks the current read position.
Wraps any type implementing [AsRef<[u8]>] and provides seeking and reading
operations while maintaining an internal cursor position.
See BufReader::from_slice for construction.
Implementations
Sourceimpl<S> BufReader<S>
impl<S> BufReader<S>
Sourcepub fn from_slice(s: S) -> Self
pub fn from_slice(s: S) -> Self
Creates a new BufReader wrapping the provided byte slice.
The reader’s position is initialized to 0.
Examples
use pure_magic::readers::{BufReader, DataRead};
let reader = BufReader::from_slice(b"hello world");
assert_eq!(reader.stream_position(), 0);Trait Implementations
Sourceimpl<S> DataRead for BufReader<S>
impl<S> DataRead for BufReader<S>
Sourcefn stream_position(&self) -> u64
fn stream_position(&self) -> u64
Returns the current position in the data stream.
Sourcefn read_range(&mut self, range: Range<u64>) -> Result<&[u8]>
fn read_range(&mut self, range: Range<u64>) -> Result<&[u8]>
Reads a range of bytes from the data. Read more
Sourcefn read_until_any_delim_or_limit(
&mut self,
delims: &[u8],
limit: u64,
) -> Result<&[u8], Error>
fn read_until_any_delim_or_limit( &mut self, delims: &[u8], limit: u64, ) -> Result<&[u8], Error>
Reads bytes until any of the delimiters or
limit bytes is reached. Read moreSourcefn read_until_utf16_or_limit(
&mut self,
utf16_char: &[u8; 2],
limit: u64,
) -> Result<&[u8], Error>
fn read_until_utf16_or_limit( &mut self, utf16_char: &[u8; 2], limit: u64, ) -> Result<&[u8], Error>
Reads bytes until a UTF-16 character or
limit bytes is reached. Read moreSourcefn offset_from_start(&self, pos: SeekFrom) -> u64
fn offset_from_start(&self, pos: SeekFrom) -> u64
Computes the absolute byte offset from a
SeekFrom position.Sourcefn read_count(&mut self, count: u64) -> Result<&[u8], Error>
fn read_count(&mut self, count: u64) -> Result<&[u8], Error>
Reads up to
count bytes from the current position. Read moreSourcefn read_exact_range(&mut self, range: Range<u64>) -> Result<&[u8], Error>
fn read_exact_range(&mut self, range: Range<u64>) -> Result<&[u8], Error>
Reads exactly the specified byte range. Read more
Sourceimpl<S> Read for BufReader<S>
impl<S> Read for BufReader<S>
Sourcefn read(&mut self, buf: &mut [u8]) -> Result<usize>
fn read(&mut self, buf: &mut [u8]) -> Result<usize>
Pull some bytes from this source into the specified buffer, returning
how many bytes were read. Read more
1.36.0 · Sourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>
Like
read, except that it reads into a slice of buffers. Read moreSourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error>
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error>
Reads all bytes until EOF in this source, placing them into
buf. Read more1.0.0 · Sourcefn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>
Reads all bytes until EOF in this source, appending them to
buf. Read more1.6.0 · Sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>
Reads the exact number of bytes required to fill
buf. Read moreSourcefn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<(), Error>
fn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
read_buf)Pull some bytes from this source into the specified buffer. Read more
Sourcefn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<(), Error>
fn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
read_buf)Reads the exact number of bytes required to fill
cursor. Read more1.0.0 · Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates a “by reference” adapter for this instance of
Read. Read more1.0.0 · Sourcefn chain<R>(self, next: R) -> Chain<Self, R>
fn chain<R>(self, next: R) -> Chain<Self, R>
Creates an adapter which will chain this stream with another. Read more